@@ -82,16 +82,19 @@ class AussieBB():
             if self.debug:
                 print(f"Dumping headers: {response.headers}", file=sys.stderr)
                 print(f"Dumping response: {jsondata}", file=sys.stderr)
+            delay = 60
             if 'Please try again in ' in jsondata.get('errors'):
                 delay = jsondata.get('errors').split()[-2]
                 if int(delay) > 0 and int(delay) > 1000:
                     if self.debug:
                         print(f"Found delay: {delay}", file=sys.stderr)
                     delay = int(delay)
-                else:
-                    delay = 30
+                elif self.debug:
+                    print(f"Couldn't parse delay, using default: {delay}", file=sys.stderr)
             else:
                 delay = 60
+                if self.debug:
+                    print(f"Couldn't parse delay, using default: {delay}", file=sys.stderr)
             if wait_on_rate_limit:
                 print(f"Rate limit on Aussie API calls raised, sleeping for {delay} seconds.", file=sys.stderr)
                 await asyncio.sleep(delay)
